@@ -22,7 +22,7 @@ class Plugin(ABC):
 class Plugins(object):
     def __init__(self, package: str, names: Optional[list] = None):
         self.package: str = package
-        self.names: Optional[list] = names or []
+        self.names: list = names or []
         self.reload()
 
     def reload(self) -> None:
@@ -81,6 +81,8 @@ class Plugins(object):
                     _id=doc["_id"],
                     _index=doc["_index"],
                 )
+                if not doc["_source"]:
+                    yield
             yield doc
 
     def auth(self, key: str) -> Optional[str]:
