@@ -29,6 +29,8 @@ LOG_INTERVAL = env.float("LOG_INTERVAL", default=0.5)
 # page block size
 BLOCK_SIZE = env.int("BLOCK_SIZE", default=2048 * 10)
 QUERY_LITERAL_BINDS = env.bool("QUERY_LITERAL_BINDS", default=None)
+# number of threads to spawn for poll db
+NTHREADS_POLLDB = env.int("NTHREADS_POLLDB", default=1)
 
 # Elasticsearch:
 ELASTICSEARCH_SCHEME = env.str("ELASTICSEARCH_SCHEME", default="http")
