@@ -277,7 +277,7 @@ class TestNestedChildren(object):
         except Exception:
             raise
 
-        sync.redis._delete()
+        sync.redis.delete()
         session.connection().engine.connect().close()
         session.connection().engine.dispose()
         sync.es.close()
@@ -380,7 +380,7 @@ class TestNestedChildren(object):
         docs = [doc for doc in sync.sync()]
         assert len(docs) == 3
         docs = sorted(docs, key=lambda k: k["_id"])
-        assert docs == [
+        expected = [
             {
                 "_id": "abc",
                 "_index": "testdb",
@@ -398,19 +398,6 @@ class TestNestedChildren(object):
                         "subject": {"id": [1, 4, 5]},
                     },
                     "authors": [
-                        {
-                            "city_label": {
-                                "country_label": {
-                                    "continent_label": {"name": "Europe"},
-                                    "id": 1,
-                                    "name": "United Kingdom",
-                                },
-                                "id": 1,
-                                "name": "Cardiff",
-                            },
-                            "id": 1,
-                            "name": "Roald Dahl",
-                        },
                         {
                             "city_label": {
                                 "country_label": {
@@ -424,6 +411,19 @@ class TestNestedChildren(object):
                             "id": 4,
                             "name": "Kermit D Frog",
                         },
+                        {
+                            "city_label": {
+                                "country_label": {
+                                    "continent_label": {"name": "Europe"},
+                                    "id": 1,
+                                    "name": "United Kingdom",
+                                },
+                                "id": 1,
+                                "name": "Cardiff",
+                            },
+                            "id": 1,
+                            "name": "Roald Dahl",
+                        },
                     ],
                     "book_languages": [
                         {"book_isbn": "abc", "language_id": 1},
@@ -456,19 +456,6 @@ class TestNestedChildren(object):
                         "subject": {"id": [2, 4, 5]},
                     },
                     "authors": [
-                        {
-                            "city_label": {
-                                "country_label": {
-                                    "continent_label": {"name": "Europe"},
-                                    "id": 1,
-                                    "name": "United Kingdom",
-                                },
-                                "id": 1,
-                                "name": "Cardiff",
-                            },
-                            "id": 1,
-                            "name": "Roald Dahl",
-                        },
                         {
                             "city_label": {
                                 "country_label": {
@@ -482,6 +469,19 @@ class TestNestedChildren(object):
                             "id": 2,
                             "name": "Haruki Murakami",
                         },
+                        {
+                            "city_label": {
+                                "country_label": {
+                                    "continent_label": {"name": "Europe"},
+                                    "id": 1,
+                                    "name": "United Kingdom",
+                                },
+                                "id": 1,
+                                "name": "Cardiff",
+                            },
+                            "id": 1,
+                            "name": "Roald Dahl",
+                        },
                     ],
                     "book_languages": [
                         {"book_isbn": "def", "language_id": 1},
@@ -513,19 +513,6 @@ class TestNestedChildren(object):
                         "subject": {"id": [3, 5]},
                     },
                     "authors": [
-                        {
-                            "city_label": {
-                                "country_label": {
-                                    "continent_label": {"name": "Asia"},
-                                    "id": 2,
-                                    "name": "Japan",
-                                },
-                                "id": 2,
-                                "name": "Kyoto",
-                            },
-                            "id": 2,
-                            "name": "Haruki Murakami",
-                        },
                         {
                             "city_label": {
                                 "country_label": {
@@ -539,6 +526,19 @@ class TestNestedChildren(object):
                             "id": 3,
                             "name": "Alejo Carpentier",
                         },
+                        {
+                            "city_label": {
+                                "country_label": {
+                                    "continent_label": {"name": "Asia"},
+                                    "id": 2,
+                                    "name": "Japan",
+                                },
+                                "id": 2,
+                                "name": "Kyoto",
+                            },
+                            "id": 2,
+                            "name": "Haruki Murakami",
+                        },
                     ],
                     "book_languages": [
                         {"book_isbn": "ghi", "language_id": 1},
@@ -556,6 +556,30 @@ class TestNestedChildren(object):
                 },
             },
         ]
+
+        for i, doc in enumerate(docs):
+            assert doc["_id"] == expected[i]["_id"]
+            assert doc["_index"] == expected[i]["_index"]
+            for key in [
+                "_meta",
+                "authors",
+                "book_languages",
+                "description",
+                "isbn",
+                "languages",
+                "publisher_label",
+                "subjects",
+                "title",
+            ]:
+                if key == "authors":
+                    assert sorted(
+                        doc["_source"][key], key=lambda k: k["id"]
+                    ) == sorted(
+                        expected[i]["_source"][key], key=lambda k: k["id"]
+                    )
+                else:
+                    assert doc["_source"][key] == expected[i]["_source"][key]
+
         assert_resync_empty(sync, nodes)
 
     def test_insert_root(
@@ -793,7 +817,7 @@ class TestNestedChildren(object):
 
         assert len(docs) == 1
         docs = sorted(docs, key=lambda k: k["_id"])
-        assert docs == [
+        expected = [
             {
                 "_id": "abc",
                 "_index": "testdb",
@@ -811,19 +835,6 @@ class TestNestedChildren(object):
                         "subject": {"id": [1, 4, 5]},
                     },
                     "authors": [
-                        {
-                            "city_label": {
-                                "country_label": {
-                                    "continent_label": {"name": "Europe"},
-                                    "id": 1,
-                                    "name": "United Kingdom",
-                                },
-                                "id": 1,
-                                "name": "Cardiff",
-                            },
-                            "id": 1,
-                            "name": "Roald Dahl",
-                        },
                         {
                             "city_label": {
                                 "country_label": {
@@ -837,6 +848,19 @@ class TestNestedChildren(object):
                             "id": 4,
                             "name": "Kermit D Frog",
                         },
+                        {
+                            "city_label": {
+                                "country_label": {
+                                    "continent_label": {"name": "Europe"},
+                                    "id": 1,
+                                    "name": "United Kingdom",
+                                },
+                                "id": 1,
+                                "name": "Cardiff",
+                            },
+                            "id": 1,
+                            "name": "Roald Dahl",
+                        },
                     ],
                     "book_languages": [
                         {"book_isbn": "abc", "language_id": 1},
@@ -853,6 +877,29 @@ class TestNestedChildren(object):
                 },
             }
         ]
+        for i, doc in enumerate(docs):
+            assert doc["_id"] == expected[i]["_id"]
+            assert doc["_index"] == expected[i]["_index"]
+            for key in [
+                "_meta",
+                "authors",
+                "book_languages",
+                "description",
+                "isbn",
+                "languages",
+                "publisher_label",
+                "subjects",
+                "title",
+            ]:
+                if key == "authors":
+                    assert sorted(
+                        doc["_source"][key], key=lambda k: k["id"]
+                    ) == sorted(
+                        expected[i]["_source"][key], key=lambda k: k["id"]
+                    )
+                else:
+                    assert doc["_source"][key] == expected[i]["_source"][key]
+
         assert_resync_empty(sync, nodes)
         sync.es.close()
 
@@ -937,7 +984,7 @@ class TestNestedChildren(object):
 
         assert len(docs) == 2
         docs = sorted(docs, key=lambda k: k["isbn"])
-        assert docs == [
+        expected = [
             {
                 "_meta": {
                     "author": {"id": [1, 2]},
@@ -952,19 +999,6 @@ class TestNestedChildren(object):
                     "subject": {"id": [2, 4, 5]},
                 },
                 "authors": [
-                    {
-                        "city_label": {
-                            "country_label": {
-                                "continent_label": {"name": "Europe"},
-                                "id": 1,
-                                "name": "United Kingdom",
-                            },
-                            "id": 1,
-                            "name": "Cardiff",
-                        },
-                        "id": 1,
-                        "name": "Roald Dahl",
-                    },
                     {
                         "city_label": {
                             "country_label": {
@@ -978,6 +1012,19 @@ class TestNestedChildren(object):
                         "id": 2,
                         "name": "Haruki Murakami",
                     },
+                    {
+                        "city_label": {
+                            "country_label": {
+                                "continent_label": {"name": "Europe"},
+                                "id": 1,
+                                "name": "United Kingdom",
+                            },
+                            "id": 1,
+                            "name": "Cardiff",
+                        },
+                        "id": 1,
+                        "name": "Roald Dahl",
+                    },
                 ],
                 "book_languages": [
                     {"book_isbn": "def", "language_id": 1},
@@ -1005,19 +1052,6 @@ class TestNestedChildren(object):
                     "subject": {"id": [3, 5]},
                 },
                 "authors": [
-                    {
-                        "city_label": {
-                            "country_label": {
-                                "continent_label": {"name": "Asia"},
-                                "id": 2,
-                                "name": "Japan",
-                            },
-                            "id": 2,
-                            "name": "Kyoto",
-                        },
-                        "id": 2,
-                        "name": "Haruki Murakami",
-                    },
                     {
                         "city_label": {
                             "country_label": {
@@ -1031,6 +1065,19 @@ class TestNestedChildren(object):
                         "id": 3,
                         "name": "Alejo Carpentier",
                     },
+                    {
+                        "city_label": {
+                            "country_label": {
+                                "continent_label": {"name": "Asia"},
+                                "id": 2,
+                                "name": "Japan",
+                            },
+                            "id": 2,
+                            "name": "Kyoto",
+                        },
+                        "id": 2,
+                        "name": "Haruki Murakami",
+                    },
                 ],
                 "book_languages": [
                     {"book_isbn": "ghi", "language_id": 1},
@@ -1044,6 +1091,25 @@ class TestNestedChildren(object):
                 "title": "The Rabbit Club",
             },
         ]
+        for i, doc in enumerate(docs):
+            for key in [
+                "_meta",
+                "authors",
+                "book_languages",
+                "description",
+                "isbn",
+                "languages",
+                "publisher_label",
+                "subjects",
+                "title",
+            ]:
+                if key == "authors":
+                    assert sorted(doc[key], key=lambda k: k["id"]) == sorted(
+                        expected[i][key], key=lambda k: k["id"]
+                    )
+                else:
+                    assert doc[key] == expected[i][key]
+
         assert_resync_empty(sync, nodes)
         sync.es.close()
 
@@ -1113,7 +1179,8 @@ class TestNestedChildren(object):
 
         assert len(docs) == 3
         docs = sorted(docs, key=lambda k: k["isbn"])
-        assert docs == [
+
+        expected = [
             {
                 "_meta": {
                     "author": {"id": [1, 4, 5]},
@@ -1287,6 +1354,25 @@ class TestNestedChildren(object):
                 "title": "The Rabbit Club",
             },
         ]
+        for i, doc in enumerate(docs):
+            for key in [
+                "_meta",
+                "authors",
+                "book_languages",
+                "description",
+                "isbn",
+                "languages",
+                "publisher_label",
+                "subjects",
+                "title",
+            ]:
+                if key == "authors":
+                    assert sorted(doc[key], key=lambda k: k["id"]) == sorted(
+                        expected[i][key], key=lambda k: k["id"]
+                    )
+                else:
+                    assert doc[key] == expected[i][key]
+
         assert_resync_empty(sync, nodes)
         sync.es.close()
 
@@ -1344,7 +1430,7 @@ class TestNestedChildren(object):
 
         assert len(docs) == 3
         docs = sorted(docs, key=lambda k: k["isbn"])
-        assert docs == [
+        expected = [
             {
                 "_meta": {
                     "author": {"id": [4, 5]},
@@ -1505,6 +1591,25 @@ class TestNestedChildren(object):
                 "title": "The Rabbit Club",
             },
         ]
+        for i, doc in enumerate(docs):
+            for key in [
+                "_meta",
+                "authors",
+                "book_languages",
+                "description",
+                "isbn",
+                "languages",
+                "publisher_label",
+                "subjects",
+                "title",
+            ]:
+                if key == "authors":
+                    assert sorted(doc[key], key=lambda k: k["id"]) == sorted(
+                        expected[i][key], key=lambda k: k["id"]
+                    )
+                else:
+                    assert doc[key] == expected[i][key]
+
         assert_resync_empty(sync, nodes)
         sync.es.close()
 
@@ -1536,7 +1641,7 @@ class TestNestedChildren(object):
 
         assert len(docs) == 3
         docs = sorted(docs, key=lambda k: k["isbn"])
-        assert docs == [
+        expected = [
             {
                 "_meta": {
                     "book_language": {"id": [1, 4, 7, 9]},
@@ -1665,6 +1770,25 @@ class TestNestedChildren(object):
                 "title": "The Rabbit Club",
             },
         ]
+        for i, doc in enumerate(docs):
+            for key in [
+                "_meta",
+                "authors",
+                "book_languages",
+                "description",
+                "isbn",
+                "languages",
+                "publisher_label",
+                "subjects",
+                "title",
+            ]:
+                if key == "authors" and doc[key] is not None:
+                    assert sorted(doc[key], key=lambda k: k["id"]) == sorted(
+                        expected[i][key], key=lambda k: k["id"]
+                    )
+                else:
+                    assert doc[key] == expected[i][key]
+
         assert_resync_empty(sync, nodes)
         sync.es.close()
 
